@@ -163,10 +163,10 @@ class SwerveDrivetrain(Subsystem):
         self.chassis_speeds = self.kinematics.toChassisSpeeds(module_states)
 
     def stop(self):
-        self.n_00.set(0 * m/s, 0 * rad)
-        self.n_01.set(0 * m/s, 0 * rad)
-        self.n_10.set(0 * m/s, 0 * rad)
-        self.n_11.set(0 * m/s, 0 * rad)
+        self.n_00.set(0, 0)
+        self.n_01.set(0, 0)
+        self.n_10.set(0, 0)
+        self.n_11.set(0, 0)
 
     @staticmethod
     def _calculate_swerve_node(node_x: meters, node_y: meters, dx: meters_per_second, dy: meters_per_second, d_theta: radians_per_second) -> (meters_per_second, radians):
